Glossary
========
A glossary of terms used in column names for the different tables on understat.com, divided by type of tables they can be found in

.. _Glossary - General:

.. rubric:: General

:Team:
    Team name
:M:
    Matches
:W:
    Wins
:D:
    Draws
:L:
    Losses
:G:
    Goals scored
:GA:
    Goals against
:PTS:
    Points
:xG:
    Expected goals
:xGA:
    Expected goals against
:xGD:
    The difference between xG and xGA
:NPxG:
    Expected goals excluding penalties as own goals
:NPxGA:
    Expected goals against excluding penalties and own goals
:NPxGD:
    The difference between NPxG and NPxGA
:xG90:
    xG per 90 minutes
:NPxG90:
    NPxG per 90

.. _Glossary - Team:

.. rubric:: Team

:PPDA:
    Passes allowed per defensive action in the opposition half
:OPPDA:
    Opponent passes allowed per defensive action in the opposition half
:DC:
    Passes completed within 20 yards of goal (excluding crosses)
:ODC:
    Opponent passes completed within 20 yards of goal (excluding crosses)
:xPTS:
    Expected points

.. _Glossary - Players:

.. rubric:: Players

:Player:
    Player name
:Pos:
    Position
:Apps:
    Appearances
:Min:
    Minutes
:NPG:
    Non penalty goals
:A:
    Assists
:xA:
    The sum of the xG of shots from a players key passes
:xA90:
    Expected assists per 90
:KP90:
    Key passes per 90
:xGChain:
    The total xG of every posession the player is involved in
:xGBuildop:
    The total xG of every posession the player is involved in excluding key passes and shots
:Sh90:
    Shots per 90
:xA90:
    xA per 90
:xG90 + xA90:
    xG90 plus xA90
:NPxG90 + xA90:
    NPxg90 plus xA90
:xGChain90:
    xGChain per 90
:xGBuildup90:
    xGBuildup per 90

.. _Glossary - Match Context:

.. rubric:: Match Context

:Formation:
    Formation
:Game state:
    Current goal difference
:Timing:
    Current time in the match, broken down into 15 minute intervals
:Shot zones:
    Zones where shots are taken from
:Attack speed:
    Speed og the attack
:Result:
    Outcome of a shot
:Sh:
    Shots
:ShA:
    Shots against
:xG/Sh:
    Expected goals per shot
:xGA/Sh:
    Expected goals against per shot
